@@ -3,7 +3,8 @@ from __future__ import unicode_literals
 
 from django.db import models
 from django.conf import settings
-from .commons.models import BaseModel
+from mpesa.commons.models import BaseModel
+
 
 # Create your models here.
 class PaymentTransaction(models.Model):
@@ -29,4 +30,4 @@ class Wallet(BaseModel):
     date_created = models.DateTimeField(auto_now=False, auto_now_add=True, null=True)
 
     def __str__(self):
-        return self.phone_number
\ No newline at end of file
+        return self.phone_number
